@@ -1,4 +1,4 @@
-/* $Id: smp.c,v 1.10 2004/03/04 15:29:10 hadess Exp $ */
+/* $Id: smp.c,v 1.12 2004/06/09 18:52:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,9 @@
 #include <config.h>
 
 #include <locale.h>
+#include <libintl.h>
 #include <math.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/cpu.h>
@@ -45,7 +47,7 @@ main (int argc, char *argv [])
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
-	
+
 	glibtop_init();
 
 	glibtop_get_cpu (&cpu);
@@ -100,7 +102,7 @@ main (int argc, char *argv [])
 	printf ("%-26s %12s %12s %12s %12s %12s\n%s\n", _("Percent:"),
 		_("Total (%)"), _("User (%)"), _("Nice (%)"), _("Sys (%)"),
 		_("Idle (%)"), separator);
-	
+
 	printf (_("CPU          (0x%08lx): %12.3f %12.3f %12.3f %12.3f %12.3f\n\n"),
 		(unsigned long) cpu.flags, (double) total * 100.0 / total,
 		(double) user  * 100.0 / total,
