@@ -1,4 +1,4 @@
-/* $Id: command.h,v 1.28 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: command.h,v 1.31 2004/11/13 00:53:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -57,8 +57,9 @@ G_BEGIN_DECLS
 #define GLIBTOP_CMND_FSUSAGE		21
 #define GLIBTOP_CMND_NETLOAD		22
 #define GLIBTOP_CMND_PPP		23
+#define GLIBTOP_CMND_NETLIST		24
 
-#define GLIBTOP_MAX_CMND		24
+#define GLIBTOP_MAX_CMND		25
 
 #define _GLIBTOP_PARAM_SIZE		16
 
@@ -69,8 +70,8 @@ typedef union  _glibtop_response_union	glibtop_response_union;
 
 struct _glibtop_command
 {
-	u_int64_t	command;
-	u_int64_t	size, data_size;
+	guint64	command;
+	guint64	size, data_size;
 	char		parameter [_GLIBTOP_PARAM_SIZE];
 };
 
@@ -82,8 +83,8 @@ union _glibtop_response_union
 
 struct _glibtop_response
 {
-	int64_t offset;
-	u_int64_t size, data_size;
+	gint64 offset;
+	guint64 size, data_size;
 	glibtop_response_union u;
 };
 
