@@ -1,4 +1,4 @@
-/* $Id: sysdeps.h,v 1.33 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: sysdeps.h,v 1.34 2004/11/13 00:53:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -51,8 +51,9 @@ G_BEGIN_DECLS
 #define GLIBTOP_SYSDEPS_FSUSAGE		20
 #define GLIBTOP_SYSDEPS_NETLOAD		21
 #define GLIBTOP_SYSDEPS_PPP		22
+#define GLIBTOP_SYSDEPS_NETLIST		23
 
-#define GLIBTOP_MAX_SYSDEPS		23
+#define GLIBTOP_MAX_SYSDEPS		24
 
 #define GLIBTOP_SYSDEPS_ALL		((1 << GLIBTOP_MAX_SYSDEPS) - 1)
 
@@ -86,6 +87,7 @@ struct _glibtop_sysdeps
 		proc_map,		/* glibtop_proc_map	*/
 		mountlist,		/* glibtop_mountlist	*/
 		fsusage,		/* glibtop_fsusage	*/
+		netlist,		/* glibtop_netlist	*/
 		netload,		/* glibtop_netload	*/
 		ppp;			/* glibtop_ppp		*/
 };
