@@ -1,3 +1,5 @@
+/* $Id: union.h,v 1.20 2004/11/13 00:53:20 bdejean Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -41,9 +43,6 @@
 #include <glibtop/procsegment.h>
 #include <glibtop/procargs.h>
 #include <glibtop/procmap.h>
-#include <glibtop/procopenfiles.h>
-#include <glibtop/procwd.h>
-#include <glibtop/procaffinity.h>
 
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
@@ -81,9 +80,6 @@ union _glibtop_union
 	glibtop_netlist		netlist;
 	glibtop_netload		netload;
 	glibtop_ppp		ppp;
-	glibtop_proc_open_files proc_open_files;
-	glibtop_proc_wd		proc_wd;
-	glibtop_proc_affinity	proc_affinity;
 };
 
 G_END_DECLS
