@@ -312,7 +312,7 @@ glibtop_get_sem_limits_l (glibtop *server, glibtop_sem_limits *buf)
 
 unsigned *
 glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
-                        int64_t which, int64_t arg)
+                        gint64 which, gint64 arg)
 {
 	const void *send_ptr = &which;
 	const size_t send_size =
@@ -810,3 +810,41 @@ glibtop_get_ppp_l (glibtop *server, glibtop_ppp *buf,
 					  &server->required.ppp);
 }
 
+char **
+glibtop_get_netlist_l (glibtop *server, glibtop_netlist *buf)
+{
+	const void *send_ptr = NULL;
+	const size_t send_size = 0;
+	char ** retval = (char **) 0;
+
+	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_NETLIST), 0);
+
+	/* If neccessary, we ask the server for the requested
+	 * feature. If not, we call the sysdeps function. */
+
+	if ((server->flags & _GLIBTOP_INIT_STATE_SERVER) &&
+	    (server->features & (1 << GLIBTOP_SYSDEPS_NETLIST)))
+	{
+		retval = glibtop_call_l (server, GLIBTOP_CMND_NETLIST,
+				         send_size, send_ptr,
+				         sizeof (glibtop_netlist), buf);
+	} else {
+#if (!GLIBTOP_SUID_NETLIST)
+		retval = glibtop_get_netlist_s (server, buf);
+#else
+		errno = ENOSYS;
+		glibtop_error_io_r (server, "glibtop_get_netlist");
+#endif
+	}
+
+	/* Make sure that all required fields are present. */
+
+	if (buf->flags & server->required.netlist)
+		_glibtop_missing_feature (server, "netlist", buf->flags,
+					  &server->required.netlist);
+
+	/* Now we can return. */
+
+	return retval;
+}
+
