@@ -1,4 +1,4 @@
-/* $Id: ppp.c,v 1.18 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: ppp.c,v 1.19 2004/08/28 20:55:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,7 +39,7 @@
 #include <net/netisr.h>
 #include <net/route.h>
 
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
 #include <net/if_sppp.h>
 #else
 #include <i4b/sppp/if_sppp.h>
