@@ -1,4 +1,4 @@
-/* $Id: procmem.c,v 1.31 2004/03/09 23:13:31 hadess Exp $ */
+/* $Id: procmem.c,v 1.33 2004/07/18 20:33:56 bdejean Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -129,7 +129,7 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 	int count;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MEM), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_mem));
 
 	if (server->sysdeps.proc_mem == 0)
@@ -137,7 +137,7 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 
 	/* It does not work for the swapper task. */
 	if (pid == 0) return;
-	
+
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
 	if ((pinfo == NULL) || (count < 1)) {
@@ -150,10 +150,10 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 
        buf->rss_rlim = pinfo [0].ki_rssize;
 
-       buf->vsize = buf->size = (u_int64_t) pagetok
+       buf->vsize = buf->size = (guint64) pagetok
                (pinfo [0].ki_tsize + pinfo [0].ki_dsize + pinfo[0].ki_ssize)
                        << LOG1024;
-       buf->resident = buf->rss = (u_int64_t) pagetok
+       buf->resident = buf->rss = (guint64) pagetok
                (pinfo [0].ki_rssize) << LOG1024;
 
 #else
@@ -167,14 +167,14 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 		return;
 	}
 
-	buf->rss_rlim = (guint64) 
+	buf->rss_rlim = (guint64)
 		(plimit.pl_rlimit [RLIMIT_RSS].rlim_cur);
-	
+
 	vms = &pinfo [0].kp_eproc.e_vm;
 
 	buf->vsize = buf->size = (guint64) pagetok
 		(vms->vm_tsize + vms->vm_dsize + vms->vm_ssize) << LOG1024;
-	
+
 	buf->resident = buf->rss = (guint64) pagetok
 		(vms->vm_rssize) << LOG1024;
 #endif
