@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.18 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: uptime.c,v 1.22 2004/11/28 01:32:55 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -25,7 +25,11 @@
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
 
-static unsigned long _glibtop_sysdeps_uptime =
+#include "glibtop_private.h"
+
+#include <time.h>
+
+static const unsigned long _glibtop_sysdeps_uptime =
 (1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
 
 /* Init function. */
@@ -44,26 +48,16 @@ void
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
 	char buffer [BUFSIZ], *p;
-	int fd, len;
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
 
 	memset (buf, 0, sizeof (glibtop_uptime));
 
-	fd = open (FILENAME, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", FILENAME);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", FILENAME);
-
-	close (fd);
-
-	buffer [len] = '\0';
+	file_to_buffer(server, buffer, FILENAME);
 
 	buf->uptime   = strtod (buffer, &p);
 	buf->idletime = strtod (p, &p);
+	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
