@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.8 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: glibtop_machine.h,v 1.9 2003/10/20 15:20:05 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,7 +32,7 @@
 #undef user
 #undef idle
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 int table (int id, int index, char *addr, int nel, u_int lel);
 
@@ -45,6 +45,6 @@ struct _glibtop_machine
 	unsigned proctable_entries;	/* Max entries in the proctable */
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
