@@ -1,4 +1,4 @@
-/* $Id: glibtop_server.h,v 1.10 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: glibtop_server.h,v 1.11 2003/10/20 15:20:05 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		0
 #define GLIBTOP_SUID_MEM		0
@@ -47,6 +47,6 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
